@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -43,7 +44,6 @@
 #include <comphelper/sequence.hxx>
 
 #include <tools/debug.hxx>
-#include <tools/list.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/window.hxx>
 
@@ -74,8 +74,6 @@ public:
     inline const uno::Reference< awt::XControl >&   getControl() const { return mxControl; }
 };
 
-//DECLARE_LIST( UnoControlHolderList, UnoControlHolder* );
-
 class UnoControlHolderList
 {
 public:
@@ -412,13 +410,16 @@ void SAL_CALL DialogStepChangedListener::propertyChange( const	beans::PropertyCh
 //	----------------------------------------------------
 //	class UnoControlContainer
 //	----------------------------------------------------
-UnoControlContainer::UnoControlContainer() : maCListeners( *this )
+UnoControlContainer::UnoControlContainer( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& i_factory )
+    :UnoControlContainer_Base( i_factory )
+    ,maCListeners( *this )
 {
     mpControls = new UnoControlHolderList;
 }
 
-UnoControlContainer::UnoControlContainer( uno::Reference< awt::XWindowPeer >  xP )
-    :	maCListeners( *this )
+UnoControlContainer::UnoControlContainer( const uno::Reference< lang::XMultiServiceFactory >& i_factory, const uno::Reference< awt::XWindowPeer >& xP )
+    :UnoControlContainer_Base( i_factory )
+    ,maCListeners( *this )
 {
     setPeer( xP );
     mbDisposePeer = sal_False;
@@ -642,7 +643,7 @@ void UnoControlContainer::impl_createControlPeerIfNecessary( const uno::Referenc
 
     // if the container already has a peer, then also create a peer for the control
     uno::Reference< awt::XWindowPeer > xMyPeer( getPeer() );
-    
+
     if( xMyPeer.is() )
     {
         _rxControl->createPeer( NULL, xMyPeer );
@@ -808,8 +809,8 @@ void UnoControlContainer::createPeer( const uno::Reference< awt::XToolkit >& rxT
                 aCtrls.getArray()[n]->createPeer( rxToolkit, getPeer() );
 
             uno::Reference< awt::XVclContainerPeer >  xC( getPeer(), uno::UNO_QUERY );
-
-            xC->enableDialogControl( sal_True );
+            if ( xC.is() )
+                xC->enableDialogControl( sal_True );
             ImplActivateTabControllers();
         }
 
@@ -832,3 +833,4 @@ void UnoControlContainer::setVisible( sal_Bool bVisible ) throw(uno::RuntimeExce
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
