@@ -45,7 +45,7 @@ SvStream& operator>>( SvStream& rIStream, Pair& rPair )
         int 			i;
         int 			i1;
         int 			i2;
-        UINT32			nNum;
+        sal_uInt32			nNum;
 
         rIStream >> cId;
         i1 = (cId & 0x70) >> 4;
@@ -62,7 +62,7 @@ SvStream& operator>>( SvStream& rIStream, Pair& rPair )
         }
         if ( cId & 0x80 )
             nNum ^= 0xFFFFFFFF;
-        rPair.nA = (INT32)nNum;
+        rPair.nA = (sal_Int32)nNum;
 
         nNum = 0;
         i = i1+i2;
@@ -74,7 +74,7 @@ SvStream& operator>>( SvStream& rIStream, Pair& rPair )
         }
         if ( cId & 0x08 )
             nNum ^= 0xFFFFFFFF;
-        rPair.nB = (INT32)nNum;
+        rPair.nB = (sal_Int32)nNum;
     }
     else
     {
@@ -94,11 +94,11 @@ SvStream& operator<<( SvStream& rOStream, const Pair& rPair )
     {
         unsigned char	cAry[9];
         int 			i = 1;
-        UINT32			nNum;
+        sal_uInt32			nNum;
 
         cAry[0] = 0;
 
-        nNum = (UINT32)(INT32)rPair.nA;
+        nNum = (sal_uInt32)(sal_Int32)rPair.nA;
         if ( rPair.nA < 0 )
         {
             cAry[0] |= 0x80;
@@ -139,7 +139,7 @@ SvStream& operator<<( SvStream& rOStream, const Pair& rPair )
                 cAry[0] |= 0x10;
         }
 
-        nNum = (UINT32)(INT32)rPair.nB;
+        nNum = (sal_uInt32)(sal_Int32)rPair.nB;
         if ( rPair.nB < 0 )
         {
             cAry[0] |= 0x08;
@@ -194,10 +194,6 @@ SvStream& operator<<( SvStream& rOStream, const Pair& rPair )
 |*
 |*    Rectangle::SetSize()
 |*
-|*    Beschreibung      GEN.SDW
-|*    Ersterstellung    DV 29.10.91
-|*    Letzte Aenderung  MM 21.04.94
-|*
 *************************************************************************/
 
 void Rectangle::SetSize( const Size& rSize )
@@ -221,10 +217,6 @@ void Rectangle::SetSize( const Size& rSize )
 |*
 |*    Rectangle::Union()
 |*
-|*    Beschreibung      GEN.SDW
-|*    Ersterstellung    TH 20.10.92
-|*    Letzte Aenderung  MM 21.04.94
-|*
 *************************************************************************/
 
 Rectangle& Rectangle::Union( const Rectangle& rRect )
@@ -249,10 +241,6 @@ Rectangle& Rectangle::Union( const Rectangle& rRect )
 |*
 |*    Rectangle::Intersection()
 |*
-|*    Beschreibung      GEN.SDW
-|*    Ersterstellung    TH 20.10.92
-|*    Letzte Aenderung  MM 21.04.94
-|*
 *************************************************************************/
 
 Rectangle& Rectangle::Intersection( const Rectangle& rRect )
@@ -287,10 +275,6 @@ Rectangle& Rectangle::Intersection( const Rectangle& rRect )
 |*
 |*    Rectangle::Justify()
 |*
-|*    Beschreibung      GEN.SDW
-|*    Ersterstellung    DV 07.03.91
-|*    Letzte Aenderung  DV 07.03.91
-|*
 *************************************************************************/
 
 void Rectangle::Justify()
@@ -318,37 +302,33 @@ void Rectangle::Justify()
 |*
 |*    Rectangle::IsInside()
 |*
-|*    Beschreibung      GEN.SDW
-|*    Ersterstellung    TH 19.03.90
-|*    Letzte Aenderung  MM 21.04.94
-|*
 *************************************************************************/
 
-BOOL Rectangle::IsInside( const Point& rPoint ) const
+sal_Bool Rectangle::IsInside( const Point& rPoint ) const
 {
     if ( IsEmpty() )
-        return FALSE;
+        return sal_False;
 
-    BOOL bRet = TRUE;
+    sal_Bool bRet = sal_True;
     if ( nLeft <= nRight )
     {
         if ( (rPoint.X() < nLeft) || (rPoint.X() > nRight) )
-            bRet = FALSE;
+            bRet = sal_False;
     }
     else
     {
         if ( (rPoint.X() > nLeft) || (rPoint.X() < nRight) )
-            bRet = FALSE;
+            bRet = sal_False;
     }
     if ( nTop <= nBottom )
     {
         if ( (rPoint.Y() < nTop) || (rPoint.Y() > nBottom) )
-            bRet = FALSE;
+            bRet = sal_False;
     }
     else
     {
         if ( (rPoint.Y() > nTop) || (rPoint.Y() < nBottom) )
-            bRet = FALSE;
+            bRet = sal_False;
     }
     return bRet;
 }
@@ -357,31 +337,23 @@ BOOL Rectangle::IsInside( const Point& rPoint ) const
 |*
 |*    Rectangle::IsInside()
 |*
-|*    Beschreibung      GEN.SDW
-|*    Ersterstellung    TH 19.03.90
-|*    Letzte Aenderung  MM 21.04.94
-|*
 *************************************************************************/
 
-BOOL Rectangle::IsInside( const Rectangle& rRect ) const
+sal_Bool Rectangle::IsInside( const Rectangle& rRect ) const
 {
     if ( IsInside( rRect.TopLeft() ) && IsInside( rRect.BottomRight() ) )
-        return TRUE;
+        return sal_True;
     else
-        return FALSE;
+        return sal_False;
 }
 
 /*************************************************************************
 |*
 |*    Rectangle::IsOver()
 |*
-|*    Beschreibung      GEN.SDW
-|*    Ersterstellung    TH 19.03.90
-|*    Letzte Aenderung  MM 21.04.94
-|*
 *************************************************************************/
 
-BOOL Rectangle::IsOver( const Rectangle& rRect ) const
+sal_Bool Rectangle::IsOver( const Rectangle& rRect ) const
 {
     // Wenn sie sich nicht schneiden, ueberlappen sie auch nicht
     return !GetIntersection( rRect ).IsEmpty();
@@ -403,7 +375,7 @@ SvStream& operator>>( SvStream& rIStream, Rectangle& rRect )
         int 			i2;
         int 			i3;
         int 			i4;
-        UINT32			nNum;
+        sal_uInt32			nNum;
 
         rIStream.Read( cIdAry, 2 );
         i1 = (cIdAry[0] & 0x70) >> 4;
@@ -424,7 +396,7 @@ SvStream& operator>>( SvStream& rIStream, Rectangle& rRect )
         iLast = i1;
         if ( cIdAry[0] & 0x80 )
             nNum ^= 0xFFFFFFFF;
-        rRect.nLeft = (INT32)nNum;
+        rRect.nLeft = (sal_Int32)nNum;
 
         nNum = 0;
         i = iLast+i2;
@@ -437,7 +409,7 @@ SvStream& operator>>( SvStream& rIStream, Rectangle& rRect )
         iLast += i2;
         if ( cIdAry[0] & 0x08 )
             nNum ^= 0xFFFFFFFF;
-        rRect.nTop = (INT32)nNum;
+        rRect.nTop = (sal_Int32)nNum;
 
         nNum = 0;
         i = iLast+i3;
@@ -450,7 +422,7 @@ SvStream& operator>>( SvStream& rIStream, Rectangle& rRect )
         iLast += i3;
         if ( cIdAry[1] & 0x80 )
             nNum ^= 0xFFFFFFFF;
-        rRect.nRight = (INT32)nNum;
+        rRect.nRight = (sal_Int32)nNum;
 
         nNum = 0;
         i = iLast+i4;
@@ -462,7 +434,7 @@ SvStream& operator>>( SvStream& rIStream, Rectangle& rRect )
         }
         if ( cIdAry[1] & 0x08 )
             nNum ^= 0xFFFFFFFF;
-        rRect.nBottom = (INT32)nNum;
+        rRect.nBottom = (sal_Int32)nNum;
     }
     else
     {
@@ -482,12 +454,12 @@ SvStream& operator<<( SvStream& rOStream, const Rectangle& rRect )
     {
         unsigned char	cAry[18];
         int 			i = 2;
-        UINT32			nNum;
+        sal_uInt32			nNum;
 
         cAry[0] = 0;
         cAry[1] = 0;
 
-        nNum = (UINT32)(INT32)rRect.nLeft;
+        nNum = (sal_uInt32)(sal_Int32)rRect.nLeft;
         if ( rRect.nLeft < 0 )
         {
             cAry[0] |= 0x80;
@@ -528,7 +500,7 @@ SvStream& operator<<( SvStream& rOStream, const Rectangle& rRect )
                 cAry[0] |= 0x10;
         }
 
-        nNum = (UINT32)(INT32)rRect.nTop;
+        nNum = (sal_uInt32)(sal_Int32)rRect.nTop;
         if ( rRect.nTop < 0 )
         {
             cAry[0] |= 0x08;
@@ -569,7 +541,7 @@ SvStream& operator<<( SvStream& rOStream, const Rectangle& rRect )
                 cAry[0] |= 0x01;
         }
 
-        nNum = (UINT32)(INT32)rRect.nRight;
+        nNum = (sal_uInt32)(sal_Int32)rRect.nRight;
         if ( rRect.nRight < 0 )
         {
             cAry[1] |= 0x80;
@@ -610,7 +582,7 @@ SvStream& operator<<( SvStream& rOStream, const Rectangle& rRect )
                 cAry[1] |= 0x10;
         }
 
-        nNum = (UINT32)(INT32)rRect.nBottom;
+        nNum = (sal_uInt32)(sal_Int32)rRect.nBottom;
         if ( rRect.nBottom < 0 )
         {
             cAry[1] |= 0x08;
