@@ -38,7 +38,6 @@
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <osl/diagnose.h>
-#include <i18npool/mslangid.hxx>
 #include <rtl/bootstrap.hxx>
 #include <rtl/instance.hxx>
 #if OSL_DEBUG_LEVEL > 0
@@ -377,18 +376,10 @@ Any ConfigManager::GetDirectConfigProperty(ConfigProperty eProp)
 
     Any aRet;
 
-    ::rtl::OUString sBrandName;
-#ifdef ENABLE_BROFFICE
-    LanguageType nType = MsLangId::getRealLanguage( LANGUAGE_NONE );
-    if ( nType == LANGUAGE_PORTUGUESE_BRAZILIAN )
-        sBrandName = OUString(RTL_CONSTASCII_USTRINGPARAM("BrOffice"));
-    else
-#endif
-        sBrandName = BrandName::get();
-
-    if ( eProp == PRODUCTNAME && sBrandName.getLength() )
+    ::rtl::OUString &rBrandName = BrandName::get();
+    if ( eProp == PRODUCTNAME && rBrandName.getLength() )
     {
-        aRet <<= sBrandName;
+        aRet <<= rBrandName;
         return aRet;
     }
 
@@ -536,7 +527,7 @@ Any ConfigManager::GetDirectConfigProperty(ConfigProperty eProp)
     }
 
     if ( eProp == PRODUCTNAME )
-        aRet >>= sBrandName;
+        aRet >>= rBrandName;
 
     if ( eProp == PRODUCTXMLFILEFORMATNAME )
         aRet >>= rXMLFileFormatName;
