@@ -102,12 +102,12 @@ static void	ImplPALToPAL( const BitmapBuffer& rSrcBuffer, BitmapBuffer& rDstBuff
     BitmapColor*		pColMapBuf = aColMap.ImplGetColorBuffer();
     BitmapColor			aIndex( 0 );
 
-    for( USHORT i = 0, nSrcCount = aColMap.GetEntryCount(), nDstCount = rDstBuffer.maPalette.GetEntryCount(); i < nSrcCount; i++ )
+    for( sal_uInt16 i = 0, nSrcCount = aColMap.GetEntryCount(), nDstCount = rDstBuffer.maPalette.GetEntryCount(); i < nSrcCount; i++ )
     {
         if( ( i < nDstCount ) && ( rSrcBuffer.maPalette[ i ] == rDstBuffer.maPalette[ i ] ) )
-            aIndex.SetIndex( sal::static_int_cast<BYTE>(i) );
+            aIndex.SetIndex( sal::static_int_cast<sal_uInt8>(i) );
         else
-            aIndex.SetIndex( sal::static_int_cast<BYTE>(rDstBuffer.maPalette.GetBestIndex( rSrcBuffer.maPalette[ i ] )) );
+            aIndex.SetIndex( sal::static_int_cast<sal_uInt8>(rDstBuffer.maPalette.GetBestIndex( rSrcBuffer.maPalette[ i ] )) );
 
         pColMapBuf[ i ] = aIndex;
     }
@@ -213,7 +213,7 @@ static void	ImplTCToTC( const BitmapBuffer& rSrcBuffer, BitmapBuffer& rDstBuffer
     if( BMP_SCANLINE_FORMAT( rSrcBuffer.mnFormat ) == BMP_FORMAT_24BIT_TC_BGR )
     {
         BitmapColor aCol;
-        BYTE*		pPixel;
+        sal_uInt8* pPixel = NULL;
 
         for( long nActY = 0, nMapY; nActY < nHeight; nActY++ )
         {
@@ -254,7 +254,7 @@ static void	ImplTCToPAL( const BitmapBuffer& rSrcBuffer, BitmapBuffer& rDstBuffe
     const ColorMask&	rSrcMask = rSrcBuffer.maColorMask;
     const ColorMask&	rDstMask = rDstBuffer.maColorMask;
     BitmapPalette		aColMap( rSrcBuffer.maPalette.GetEntryCount() );
-    BYTE*				pColToPalMap = new BYTE[ TC_TO_PAL_COLORS ];
+    sal_uInt8*				pColToPalMap = new sal_uInt8[ TC_TO_PAL_COLORS ];
     BitmapColor			aIndex( 0 );
 
     for( long nR = 0; nR < 16; nR++ )
@@ -263,10 +263,10 @@ static void	ImplTCToPAL( const BitmapBuffer& rSrcBuffer, BitmapBuffer& rDstBuffe
         {
             for( long nB = 0; nB < 16; nB++ )
             {
-                BitmapColor aCol( sal::static_int_cast<BYTE>(nR << 4),
-                                  sal::static_int_cast<BYTE>(nG << 4),
-                                  sal::static_int_cast<BYTE>(nB << 4) );
-                pColToPalMap[ ImplIndexFromColor( aCol ) ] = (BYTE) rDstBuffer.maPalette.GetBestIndex( aCol );
+                BitmapColor aCol( sal::static_int_cast<sal_uInt8>(nR << 4),
+                                  sal::static_int_cast<sal_uInt8>(nG << 4),
+                                  sal::static_int_cast<sal_uInt8>(nB << 4) );
+                pColToPalMap[ ImplIndexFromColor( aCol ) ] = (sal_uInt8) rDstBuffer.maPalette.GetBestIndex( aCol );
             }
         }
     }
@@ -294,7 +294,7 @@ static void	ImplTCToPAL( const BitmapBuffer& rSrcBuffer, BitmapBuffer& rDstBuffe
 // ---------------------
 
 BitmapBuffer* StretchAndConvert( const BitmapBuffer& rSrcBuffer, const SalTwoRect& rTwoRect, 
-                                 ULONG nDstBitmapFormat, BitmapPalette* pDstPal, ColorMask* pDstMask )
+                                 sal_uLong nDstBitmapFormat, BitmapPalette* pDstPal, ColorMask* pDstMask )
 {
     FncGetPixel		pFncGetPixel;
     FncSetPixel		pFncSetPixel;
@@ -326,12 +326,12 @@ BitmapBuffer* StretchAndConvert( const BitmapBuffer& rSrcBuffer, const SalTwoRec
             // initialize pFncGetPixel to something valid that is
             // least likely to crash
             pFncGetPixel = BitmapReadAccess::GetPixelFor_1BIT_MSB_PAL;
-            DBG_ERROR( "unknown read format" );
+            OSL_FAIL( "unknown read format" );
         break;
     }
 
     // set function for setting pixels
-    const ULONG nDstScanlineFormat = BMP_SCANLINE_FORMAT( nDstBitmapFormat );
+    const sal_uLong nDstScanlineFormat = BMP_SCANLINE_FORMAT( nDstBitmapFormat );
     switch( nDstScanlineFormat )
     {
         IMPL_CASE_SET_FORMAT( _1BIT_MSB_PAL, 1 );
@@ -357,7 +357,7 @@ BitmapBuffer* StretchAndConvert( const BitmapBuffer& rSrcBuffer, const SalTwoRec
             // least likely to crash
             pFncSetPixel = BitmapReadAccess::SetPixelFor_1BIT_MSB_PAL;
             pDstBuffer->mnBitCount = 1;
-            DBG_ERROR( "unknown write format" );
+            OSL_FAIL( "unknown write format" );
         break;
     }
 
@@ -368,7 +368,7 @@ BitmapBuffer* StretchAndConvert( const BitmapBuffer& rSrcBuffer, const SalTwoRec
     pDstBuffer->mnScanlineSize = AlignedWidth4Bytes( pDstBuffer->mnBitCount * pDstBuffer->mnWidth );
     try
     {
-        pDstBuffer->mpBits = new BYTE[ pDstBuffer->mnScanlineSize * pDstBuffer->mnHeight ];
+        pDstBuffer->mpBits = new sal_uInt8[ pDstBuffer->mnScanlineSize * pDstBuffer->mnHeight ];
     }
     catch( const std::bad_alloc& )
     {
